Version 1.0 ～2.0
=================

Version1.0～2.0までのリリースノートです。

## :package: 1.2.2

:fontawesome-solid-calendar: `2019-06-21`

!!! bug "content-typeが未指定のレスポンスが存在すると強制終了する不具合を修正しました"

## :package: 1.2.1

:fontawesome-solid-calendar: `2019-06-20`

!!! note "Python3.8をサポートに加えました"

??? bug "content-typeが***/octet-streamの場合に処理が重くなる不具合を修正しました"

    * エンコーディングを推測しようとして時間がかかっていました
    * バイナリなのでエンコーディングは`なし`にします

## :package: 1.2.0

:fontawesome-solid-calendar: `2019-06-20`

??? info "footprints_tagを追加しました ([res2res/json_sort])"

    * configで`footprints_tag`を指定すると、ソートで結果が変わった場合のみタグを付けることができます
    * 詳細は [res2res/json_sort] をご覧下さい

## :package: 1.1.0

:fontawesome-solid-calendar: `2019-06-04`

??? note "依存パッケージをアップグレードしました"

    * [OwlMixin]をv4.0にアップグレード

## :package: 1.0.3

:fontawesome-solid-calendar: `2019-05-07`

!!! bug "[final/notify]アドオンと[reqs2reqs/empty_guard]でnotifiersが読み込めずに終了する不具合を修正しました"

## :package: 1.0.2

:fontawesome-solid-calendar: `2019-04-23`

!!! bug "[final/notify]アドオンのリターンコードが必ず1になる不具合を修正しました"

## :package: 1.0.1

:fontawesome-solid-calendar: `2019-04-20`

??? note "依存パッケージをアップグレードしました"

    * [OwlMixin]をv3.0にアップグレード
    * urllib3を脆弱性対応版にアップグレード


[reqs2reqs/empty_guard]: ../addons/reqs2reqs.md#empty_guard
[res2res/json_sort]: ../addons/res2res.md#json_sort
[final/notify]: ../addons/final.md#notify

[OwlMixin]: https://pypi.org/project/owlmixin/
